@@ -1711,6 +1711,23 @@ class Builder(Update):
             except EmergeError:
                 self._display_error(emerge.prepare_error)
 
+    def check_vardbpkg(self, builder_path):
+        """
+        Проверка на то, что при проверке на автомагические зависимости
+        /var/db/pkg корректно восстановлен
+        :param builder_path:
+        :return:
+        """
+        vdb_path = "var/db/.pkg"
+        real_vdb_path = path.join(builder_path, VDB_PATH)
+        hide_vdb_path = path.join(builder_path, vdb_path)
+
+        if path.exists(hide_vdb_path):
+            raise BuilderError("Wrong build state: /var/db/.pkg found")
+        if not path.exists(real_vdb_path):
+            raise BuilderError(_("Wrong build state: /var/db/pkg not found"))
+        return True
+
     def check_automagic(self, builder_path):
         """
         Проверка на наличие неописанных автоматических зависимостей
